pub struct PersistentManifoldGpu {
pub body_a: u32,
pub body_b: u32,
pub points: [Option<ManifoldPoint>; 4],
pub num_points: usize,
}Expand description
Persistent 4-point contact manifold with warm-start impulse data.
Retains up to 4 contact points between a pair of bodies across frames, selecting the deepest/most-separated subset for stability.
Fields
body_a: u32Index of body A.
body_b: u32Index of body B.
points: [Option<ManifoldPoint>; 4]Retained contact points (up to 4).
num_points: usizeNumber of active contact points.
Implementations
Sourceimpl PersistentManifoldGpu
impl PersistentManifoldGpu
Sourcepub fn add_contact(&mut self, new_pt: ManifoldPoint)
pub fn add_contact(&mut self, new_pt: ManifoldPoint)
Add or replace a contact point.
If there are fewer than 4 points the new point is simply appended. Otherwise the shallowest existing point is replaced if it is shallower than the new one.
Sourcepub fn remove_stale(&mut self, threshold: f32)
pub fn remove_stale(&mut self, threshold: f32)
Remove stale contact points whose depth has become positive (separated).
Sourcepub fn reset_warm_start(&mut self)
pub fn reset_warm_start(&mut self)
Reset warm-start impulses to zero.
Sourcepub fn active_points(&self) -> impl Iterator<Item = &ManifoldPoint>
pub fn active_points(&self) -> impl Iterator<Item = &ManifoldPoint>
Return an iterator over active contact points.