pub enum CudaInitError {
NotAvailable,
FeatureNotEnabled,
NoDevice,
DeviceOrdinalOutOfRange(u32),
DeviceError(String),
CompilationError(String),
}Expand description
Errors returned by CudaBackend::try_new.
Variants
NotAvailable
CUDA runtime or driver is not installed on this system.
FeatureNotEnabled
The cuda-backend Cargo feature is not enabled in this build.
NoDevice
No CUDA-capable device found (all GPUs are AMD / Intel).
DeviceOrdinalOutOfRange(u32)
The requested device ordinal is out of range.
DeviceError(String)
cudarc device initialisation returned an error.
CompilationError(String)
NVRTC compilation of a kernel source failed.