detect_aliasing

Function detect_aliasing 

pub fn detect_aliasing(bindings: &[BufferBinding]) -> Vec<(u32, u32)>
Detect whether any buffers in a pass alias the same storage.

Two bindings alias if they reference the same BufferId with incompatible usages (e.g., one is write and the other is read in the same pass).