required_barrier

Function required_barrier 

pub fn required_barrier(
    pass_a_outputs: &[BufferId],
    pass_b_inputs: &[BufferId],
) -> PipelineBarrier
Determine the required pipeline barrier between two kernel passes.

If the output buffers of pass A overlap with the input buffers of pass B, a read-after-write barrier is needed.