pub struct GpuTimestamp {
pub start_ns: u64,
pub end_ns: u64,
}Expand description
GPU hardware timestamp pair (start / end), feature-gated to wgpu-backend.
In production use, these values are read back from a wgpu::QuerySet of
type Timestamp after the GPU has signalled completion. The raw values
are in nanoseconds (after scaling by the adapter’s timestamp period).
Fields
start_ns: u64Raw GPU timestamp at the start of the pass (nanoseconds).
end_ns: u64Raw GPU timestamp at the end of the pass (nanoseconds).
Implementations
Sourceimpl GpuTimestamp
impl GpuTimestamp
Sourcepub fn elapsed_ns(&self) -> u64
pub fn elapsed_ns(&self) -> u64
Elapsed GPU time in nanoseconds (saturating subtraction).
Sourcepub fn elapsed_ms(&self) -> f64
pub fn elapsed_ms(&self) -> f64
Elapsed GPU time in milliseconds.