pub struct WgpuBufferHandle(pub usize);Expand description
Opaque handle to a GPU buffer allocated by a ComputeBackend.
This type mirrors the one in the parent compute module so that
WgpuBackend can implement the same ComputeBackend trait.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for WgpuBufferHandle
impl Clone for WgpuBufferHandle
Sourcefn clone(&self) -> WgpuBufferHandle
fn clone(&self) -> WgpuBufferHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WgpuBufferHandle
impl Debug for WgpuBufferHandle
Sourceimpl Hash for WgpuBufferHandle
impl Hash for WgpuBufferHandle
Sourceimpl PartialEq for WgpuBufferHandle
impl PartialEq for WgpuBufferHandle
Sourcefn eq(&self, other: &WgpuBufferHandle) -> bool
fn eq(&self, other: &WgpuBufferHandle) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for WgpuBufferHandle
impl Eq for WgpuBufferHandle
impl StructuralPartialEq for WgpuBufferHandle