pub struct LBMGpuKernels {
pub f: FluidGpuBuffer,
pub collision: LBMCollisionKernelSpec,
pub streaming: LBMStreamingSpec,
pub boundary: LBMBoundaryKernelSpec,
}Expand description
GPU kernel manager for a Lattice Boltzmann Method simulation.
Stores distribution functions for all cells in a ping-pong buffer and exposes collision, streaming, and boundary dispatch methods.
Fields
f: FluidGpuBufferDouble-buffered distribution functions: Q components per cell.
collision: LBMCollisionKernelSpecCollision kernel specification.
streaming: LBMStreamingSpecStreaming kernel specification.
boundary: LBMBoundaryKernelSpecBoundary kernel specification.
Implementations
Sourceimpl LBMGpuKernels
impl LBMGpuKernels
Sourcepub fn new(
nx: usize,
ny: usize,
nz: usize,
tau: f64,
periodic: bool,
solid_cells: Vec<usize>,
) -> Self
pub fn new( nx: usize, ny: usize, nz: usize, tau: f64, periodic: bool, solid_cells: Vec<usize>, ) -> Self
Create a new LBM kernel manager.
Initialises distribution functions to the equilibrium for ρ = 1, u = 0.
Sourcepub fn dispatch_collision(&mut self)
pub fn dispatch_collision(&mut self)
Execute one BGK collision step (CPU mock).
Updates each cell’s distribution functions toward local equilibrium.
Sourcepub fn dispatch_streaming(&mut self)
pub fn dispatch_streaming(&mut self)
Execute one streaming step (CPU mock).
Propagates distribution functions to neighbouring cells.
Sourcepub fn dispatch_boundary(&mut self)
pub fn dispatch_boundary(&mut self)
Apply bounce-back boundary conditions on solid cells.