aligned_size

Function aligned_size 

pub fn aligned_size(size: usize, alignment: usize) -> usize
Compute the padded buffer size to meet alignment requirements.

Returns the smallest multiple of alignment that is >= size.