pub fn dispatch_count(total: usize, group_size: usize) -> usize
Compute the optimal work group size for a given total work item count.
Rounds up total to the next multiple of group_size.
total
group_size