pub fn gpu_loop_subdivision(mesh: &GpuMesh) -> GpuMeshExpand description
Perform one step of Loop subdivision, returning a new mesh.
Each triangle is split into four sub-triangles. New edge-midpoint vertices and updated corner vertices use the Loop weighting scheme (simplified version without full neighbour connectivity: midpoints only).