pub struct GpuParticleSystem {
pub config: EmitterConfig,
pub particles: Vec<GpuParticle>,
pub max_particles: usize,
}Expand description
GPU particle system managing emission and integration of many particles.
Fields
config: EmitterConfigEmitter configuration.
particles: Vec<GpuParticle>Currently active particles.
max_particles: usizeMaximum number of particles allowed simultaneously.
Implementations
Sourceimpl GpuParticleSystem
impl GpuParticleSystem
Sourcepub fn new(config: EmitterConfig, max_particles: usize) -> Self
pub fn new(config: EmitterConfig, max_particles: usize) -> Self
Create a new particle system with the given emitter config and capacity.
Sourcepub fn active_count(&self) -> usize
pub fn active_count(&self) -> usize
Return the number of currently alive particles.