pub struct ColorOverLife {
pub birth_color: [f32; 4],
pub death_color: [f32; 4],
pub max_life: f32,
}Expand description
Lerps a particle’s color from birth_color to death_color over its life.
Fields
birth_color: [f32; 4]Color when the particle is born (life == max_life).
death_color: [f32; 4]Color when the particle is about to die (life → 0).
max_life: f32The initial (maximum) lifetime used to compute normalised age.
Implementations
Sourceimpl ColorOverLife
impl ColorOverLife
Sourcepub fn new(birth_color: [f32; 4], death_color: [f32; 4], max_life: f32) -> Self
pub fn new(birth_color: [f32; 4], death_color: [f32; 4], max_life: f32) -> Self
Create a new color-over-life modifier.
Sourcepub fn apply(&self, particle: &mut GpuParticle)
pub fn apply(&self, particle: &mut GpuParticle)
Update the color of a single particle based on remaining life.
Sourcepub fn apply_all(&self, particles: &mut [GpuParticle])
pub fn apply_all(&self, particles: &mut [GpuParticle])
Update colors for all alive particles.