bitonic_sort

Function bitonic_sort 

pub fn bitonic_sort(data: &mut Vec<f32>)
Sort a Vecf32` in ascending order using the bitonic sort algorithm.

If data.len() is not a power of two, the vector is padded to the next power of two with f32::MAX sentinel values, sorted, then truncated.