radix_sort_f64

Function radix_sort_f64 

pub fn radix_sort_f64(data: &[f64]) -> Vec<f64>
Radix sort for f64 values (sorts by bit representation, handles sign bit).

Uses the standard trick of flipping the sign bit (and all bits for negative numbers) so that the radix sort on the bit pattern produces correct order.