pub fn build_bvh(aabbs: &[AabbGpu]) -> Vec<BvhGpuNode>Expand description
Build a BVH using a simple midpoint-split heuristic.
Returns a flat VecBvhGpuNode` with node 0 as the root.
Internal nodes reference their children by index into this vec.
pub fn build_bvh(aabbs: &[AabbGpu]) -> Vec<BvhGpuNode>Build a BVH using a simple midpoint-split heuristic.
Returns a flat VecBvhGpuNode` with node 0 as the root.
Internal nodes reference their children by index into this vec.