Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Functions

apply_impulses
Batch impulse application: apply accumulated impulses to all bodies.
batch_integrate_semi_implicit
GPU-batch semi-implicit Euler: integrate all bodies in a slice.
batch_update_world_aabbs
Batch AABB update kernel.
compute_world_aabb
Compute the world-space AABB of a rigid body given its OBB half-extents.
integrate_angular_velocity_only
Integrate only the angular velocity of each body (no linear dynamics).
integrate_euler
Euler-step all rigid bodies by dt given external forces and torques.
integrate_rk4
RK4 integration of a single rigid body for one time step.
integrate_semi_implicit
Integrate a single RigidBodyState using the semi-implicit Euler method.