pub struct SleepParams {
pub linear_threshold: f64,
pub angular_threshold: f64,
pub sleep_frames: u32,
}Expand description
Sleeping parameters used by SleepTest.
Fields
linear_threshold: f64Linear velocity threshold below which the body is considered dormant.
angular_threshold: f64Angular velocity threshold.
sleep_frames: u32Number of consecutive frames below threshold before the body sleeps.