pub struct SleepTest {
pub dormant_frames: Vec<u32>,
pub sleep_states: Vec<SleepState>,
}Expand description
Tests whether a rigid body should transition to or from sleeping.
Fields
dormant_frames: Vec<u32>Per-body consecutive dormant frame counter.
sleep_states: Vec<SleepState>Per-body current sleep state.
Implementations
Sourceimpl SleepTest
impl SleepTest
Sourcepub fn update(
&mut self,
states: &[RigidBodyState],
params: &SleepParams,
) -> usize
pub fn update( &mut self, states: &[RigidBodyState], params: &SleepParams, ) -> usize
Update sleep states for all bodies given the current states.
Returns the number of bodies that transitioned to sleep this step.
Sourcepub fn sleeping_count(&self) -> usize
pub fn sleeping_count(&self) -> usize
Return the number of sleeping bodies.