pub struct TransferQueue { /* private fields */ }Expand description
A simple upload / download transfer queue for a GPU pool.
Implementations
Sourceimpl TransferQueue
impl TransferQueue
Sourcepub fn copy_to_gpu(
&mut self,
handle: GpuBufferHandle,
offset: usize,
data: Vec<u8>,
)
pub fn copy_to_gpu( &mut self, handle: GpuBufferHandle, offset: usize, data: Vec<u8>, )
Enqueue an upload of data to handle at offset.
Sourcepub fn copy_from_gpu(
&mut self,
handle: GpuBufferHandle,
_offset: usize,
_len: usize,
)
pub fn copy_from_gpu( &mut self, handle: GpuBufferHandle, _offset: usize, _len: usize, )
Enqueue a download of len bytes from handle at offset.
Sourcepub fn execute_transfers(&mut self, pool: &mut GpuBufferPool) -> usize
pub fn execute_transfers(&mut self, pool: &mut GpuBufferPool) -> usize
Execute all pending transfers against the pool.
Returns the number of upload operations executed.
Sourcepub fn drain_downloads(&mut self) -> Vec<DownloadResult>
pub fn drain_downloads(&mut self) -> Vec<DownloadResult>
Drain completed download results.
Sourcepub fn pending_uploads(&self) -> usize
pub fn pending_uploads(&self) -> usize
Number of pending uploads.