pub struct VertexLayout {
pub pos_offset: usize,
pub normal_offset: usize,
pub uv_offset: usize,
pub stride: usize,
}Expand description
Vertex layout descriptor.
Fields
pos_offset: usizeByte offset of the position field within a vertex.
normal_offset: usizeByte offset of the normal field within a vertex.
uv_offset: usizeByte offset of the UV field within a vertex.
stride: usizeTotal vertex stride in bytes.
Implementations
Sourceimpl VertexLayout
impl VertexLayout