pub struct MultiHeadAttention {
pub d_model: usize,
pub n_heads: usize,
pub d_head: usize,
pub w_q: Vec<f64>,
pub w_k: Vec<f64>,
pub w_v: Vec<f64>,
pub w_o: Vec<f64>,
pub b_o: Vec<f64>,
}Expand description
Multi-head attention module.
Projects Q, K, V with learned linear projections, runs n_heads
parallel attention heads, then concatenates and projects the output.
All weight matrices are stored flat row-major.
Fields
d_model: usizeModel dimensionality.
n_heads: usizeNumber of attention heads.
d_head: usizeDimensionality per head: d_model / n_heads.
w_q: Vec<f64>W_Q projection [d_model × d_model].
w_k: Vec<f64>W_K projection [d_model × d_model].
w_v: Vec<f64>W_V projection [d_model × d_model].
w_o: Vec<f64>W_O output projection [d_model × d_model].
b_o: Vec<f64>Output bias [d_model].
Implementations
Sourceimpl MultiHeadAttention
impl MultiHeadAttention
Sourcepub fn new(d_model: usize, n_heads: usize) -> Self
pub fn new(d_model: usize, n_heads: usize) -> Self
Create a new MHA module with zero-initialised projections.
Sourcepub fn init_identity(&mut self)
pub fn init_identity(&mut self)
Initialise W_Q, W_K, W_V, W_O with identity-like weights for testing.
Sourcepub fn forward(&self, x: &[f64], seq_len: usize) -> Vec<f64>
pub fn forward(&self, x: &[f64], seq_len: usize) -> Vec<f64>
Forward pass.
x has shape [seq_len × d_model] (flat row-major).
Returns output of shape [seq_len × d_model].
Sourcepub fn num_params(&self) -> usize
pub fn num_params(&self) -> usize
Total number of trainable parameters.