pub enum LoadBalanceStrategy {
Static,
Weighted,
Guided,
}Expand description
Load balancing strategy for distributing work across threads.
Variants
Static
Static: divide work evenly by index count.
Weighted
Weighted: divide work so each thread gets roughly equal weight.
Guided
Guided: start with large chunks, decrease chunk size as work progresses.