pub fn compare_sorts(data: &[f64]) -> Vec<SortTimingResult>Expand description
Run all three sort algorithms on a copy of the data and verify correctness.
Returns timing results.
pub fn compare_sorts(data: &[f64]) -> Vec<SortTimingResult>Run all three sort algorithms on a copy of the data and verify correctness.
Returns timing results.