pub struct ParticleSystem {
pub buffer: ParticleBuffer,
pub emitters: Vec<ParticleEmitter>,
pub gravity: GravityForce,
pub drag: DragForce,
pub floor: Option<FloorCollision>,
pub rng: SimpleRng,
pub time: f32,
}Expand description
High-level particle system that owns a buffer, emitters, and forces.
Fields
buffer: ParticleBufferThe SoA particle data.
emitters: Vec<ParticleEmitter>All registered emitters.
gravity: GravityForceGlobal gravity.
drag: DragForceGlobal drag.
floor: Option<FloorCollision>Optional floor collision plane.
rng: SimpleRngInternal RNG for emitter seeding.
time: f32Elapsed simulation time.
Implementations
Sourceimpl ParticleSystem
impl ParticleSystem
Sourcepub fn new(capacity: usize) -> Self
pub fn new(capacity: usize) -> Self
Create a new particle system with the given buffer capacity.
Sourcepub fn add_emitter(&mut self, emitter: ParticleEmitter) -> usize
pub fn add_emitter(&mut self, emitter: ParticleEmitter) -> usize
Register an emitter and return its index.