pub struct FrameGraph { /* private fields */ }Expand description
A minimal frame graph that can validate pass dependencies.
Implementations
Sourceimpl FrameGraph
impl FrameGraph
Sourcepub fn add_pass(&mut self, pass: FrameGraphPass)
pub fn add_pass(&mut self, pass: FrameGraphPass)
Add a pass.
Sourcepub fn pass_names(&self) -> Vec<&str>
pub fn pass_names(&self) -> Vec<&str>
Return all pass names in insertion order.
Sourcepub fn writers_of(&self, resource: &str) -> Vec<&FrameGraphPass>
pub fn writers_of(&self, resource: &str) -> Vec<&FrameGraphPass>
Return all passes that write to resource.
Sourcepub fn readers_of(&self, resource: &str) -> Vec<&FrameGraphPass>
pub fn readers_of(&self, resource: &str) -> Vec<&FrameGraphPass>
Return all passes that read from resource.
Sourcepub fn validate_dependencies(&self) -> Vec<String>
pub fn validate_dependencies(&self) -> Vec<String>
Validate that all declared dependencies reference existing passes. Returns a list of invalid dependency references.
Sourcepub fn async_pass_count(&self) -> usize
pub fn async_pass_count(&self) -> usize
Count how many passes run on the async compute queue.