approximate_volume

Function approximate_volume 

pub fn approximate_volume(grid: &SdfGrid) -> f64
Compute the approximate volume enclosed by the zero level-set.

Simply counts interior cells and multiplies by cell volume.