pub struct ShaderDependencyGraph { /* private fields */ }Expand description
Tracks which shaders depend on (include) which other shaders.
When a shader is modified, all shaders that depend on it (transitively) also need to be recompiled.
Implementations
Sourceimpl ShaderDependencyGraph
impl ShaderDependencyGraph
Sourcepub fn add_dependency(
&mut self,
dependent: impl Into<String>,
dependency: impl Into<String>,
)
pub fn add_dependency( &mut self, dependent: impl Into<String>, dependency: impl Into<String>, )
Record that shader dependent depends on dependency.
Sourcepub fn direct_dependents(&self, dependency: &str) -> Vec<&str>
pub fn direct_dependents(&self, dependency: &str) -> Vec<&str>
Return all shaders that directly depend on dependency.
Sourcepub fn transitive_dependents(&self, changed_shader: &str) -> Vec<String>
pub fn transitive_dependents(&self, changed_shader: &str) -> Vec<String>
Return all shaders that transitively depend on changed_shader
(BFS / DFS over the dependency graph).
Sourcepub fn direct_dependencies(&self, shader: &str) -> &[String]
pub fn direct_dependencies(&self, shader: &str) -> &[String]
Return the direct dependencies of shader.
Sourcepub fn shaders_with_deps(&self) -> Vec<&str>
pub fn shaders_with_deps(&self) -> Vec<&str>
Return all shader names that have any recorded dependencies.