pub struct PushConstantRange {
pub offset: u32,
pub size: u32,
pub stage: ShaderStage,
}Expand description
A push constant range that can be set per draw/dispatch call.
Fields
offset: u32Byte offset into the push constant block.
size: u32Size in bytes.
stage: ShaderStageShader stage.
Implementations
Sourceimpl PushConstantRange
impl PushConstantRange
Sourcepub fn new(offset: u32, size: u32, stage: ShaderStage) -> Self
pub fn new(offset: u32, size: u32, stage: ShaderStage) -> Self
Create a new push constant range.
Sourcepub fn fits_standard_limit(&self) -> bool
pub fn fits_standard_limit(&self) -> bool
Check if this range fits within the standard 128-byte GPU limit.