pub struct ShaderTemplate {
pub template: String,
}Expand description
A parameterised WGSL shader template.
Placeholders of the form {KEY} in the template string are replaced by
the corresponding values supplied via ShaderTemplate::instantiate.
Fields
template: StringThe raw template source with {KEY} placeholders.
Implementations
Sourceimpl ShaderTemplate
impl ShaderTemplate
Sourcepub fn new(template: impl Into<String>) -> Self
pub fn new(template: impl Into<String>) -> Self
Create a new shader template from a source string.
Sourcepub fn placeholders(&self) -> Vec<String>
pub fn placeholders(&self) -> Vec<String>
Return a list of placeholder names found in the template.
Only returns names that look like valid template placeholders:
{IDENTIFIER} where IDENTIFIER is uppercase letters, digits, and
underscores, starting with an uppercase letter.