pub struct ShaderTemplateV2 {
pub source: String,
pub defines: HashMap<String, String>,
}Expand description
A parameterised shader template that replaces #define KEY tokens.
Instantiation replaces occurrences of each key found in defines
with the corresponding value. The key must appear as a whole word
(surrounded by non-identifier characters or at start/end of line).
Fields
source: StringRaw template source text.
defines: HashMap<String, String>Map from token name to replacement value.
Implementations
Sourceimpl ShaderTemplateV2
impl ShaderTemplateV2
Sourcepub fn new(source: impl Into<String>, defines: HashMap<String, String>) -> Self
pub fn new(source: impl Into<String>, defines: HashMap<String, String>) -> Self
Create a new template with the given source and defines.
Sourcepub fn instantiate(&self) -> String
pub fn instantiate(&self) -> String
Instantiate the template by performing all #define substitutions.
Each entry in defines replaces all occurrences of the key
in the source with the corresponding value.