A power-of-two bucket pool for reusing CPU-side Vec<f64> buffers.
Allocations are rounded up to the next power of two so that freed buffers can be reused for similarly-sized requests without reallocating.
Structs
- Buffer
Pool - Pool of reusable
Vec<f64>allocations, bucketed by capacity (power of two).