pub fn required_barrier(
pass_a_outputs: &[BufferId],
pass_b_inputs: &[BufferId],
) -> PipelineBarrierExpand description
Determine the required pipeline barrier between two kernel passes.
If the output buffers of pass A overlap with the input buffers of pass B, a read-after-write barrier is needed.