LBMGpuKernels

Struct LBMGpuKernels 

pub struct LBMGpuKernels {
    pub f: FluidGpuBuffer,
    pub collision: LBMCollisionKernelSpec,
    pub streaming: LBMStreamingSpec,
    pub boundary: LBMBoundaryKernelSpec,
}
GPU kernel manager for a Lattice Boltzmann Method simulation.

Stores distribution functions for all cells in a ping-pong buffer and exposes collision, streaming, and boundary dispatch methods.

Fields

f: FluidGpuBuffer

Double-buffered distribution functions: Q components per cell.

collision: LBMCollisionKernelSpec

Collision kernel specification.

streaming: LBMStreamingSpec

Streaming kernel specification.

boundary: LBMBoundaryKernelSpec

Boundary kernel specification.

Implementations

Source

impl LBMGpuKernels

pub fn new( nx: usize, ny: usize, nz: usize, tau: f64, periodic: bool, solid_cells: Vec<usize>, ) -> Self

Create a new LBM kernel manager.

Initialises distribution functions to the equilibrium for ρ = 1, u = 0.

pub fn dispatch_collision(&mut self)

Execute one BGK collision step (CPU mock).

Updates each cell’s distribution functions toward local equilibrium.

pub fn dispatch_streaming(&mut self)

Execute one streaming step (CPU mock).

Propagates distribution functions to neighbouring cells.

pub fn dispatch_boundary(&mut self)

Apply bounce-back boundary conditions on solid cells.

pub fn density_at(&self, x: usize, y: usize, z: usize) -> f64

Compute macroscopic density at cell (x, y, z).