pub struct GpuRigidBodyBatch {
pub bodies: Vec<GpuRigidBody>,
}Expand description
A batch of GPU rigid bodies supporting bulk integration.
Fields
bodies: Vec<GpuRigidBody>The rigid bodies in this batch.
Implementations
Sourceimpl GpuRigidBodyBatch
impl GpuRigidBodyBatch
Sourcepub fn add(&mut self, body: GpuRigidBody) -> usize
pub fn add(&mut self, body: GpuRigidBody) -> usize
Add a body to the batch and return its index.
Sourcepub fn integrate_all(&mut self, dt: f32, gravity: [f32; 3])
pub fn integrate_all(&mut self, dt: f32, gravity: [f32; 3])
Integrate all bodies by dt seconds under a uniform gravity (m/s²).
Uses explicit Euler integration for linear dynamics and a first-order quaternion update for rotational dynamics.