pub fn sdf_cylinder(
p: [f64; 3],
center: [f64; 3],
radius: f64,
height: f64,
) -> f64Expand description
Signed distance from point p to a finite cylinder (Y-axis aligned)
centred at center with radius radius and total height height.