pub struct GpuVoxelGrid {
pub nx: usize,
pub ny: usize,
pub nz: usize,
pub voxel_size: f64,
pub occupancy: Vec<bool>,
pub sdf: Vec<f64>,
}Expand description
A 3-D voxel grid storing binary occupancy and an SDF.
Dimensions are [nx, ny, nz] with voxel size voxel_size.
Data is stored in Z-major order: index = x + nx*(y + ny*z).
Fields
nx: usizeNumber of voxels along X.
ny: usizeNumber of voxels along Y.
nz: usizeNumber of voxels along Z.
voxel_size: f64Physical size of each voxel (assumed isotropic).
occupancy: Vec<bool>Binary occupancy: true = filled.
sdf: Vec<f64>Signed Distance Field values (positive = outside, negative = inside).
Implementations
Sourceimpl GpuVoxelGrid
impl GpuVoxelGrid
Sourcepub fn new(nx: usize, ny: usize, nz: usize, voxel_size: f64) -> Self
pub fn new(nx: usize, ny: usize, nz: usize, voxel_size: f64) -> Self
Allocate an empty voxel grid of size nx × ny × nz.
Sourcepub fn index(&self, x: usize, y: usize, z: usize) -> usize
pub fn index(&self, x: usize, y: usize, z: usize) -> usize
Flatten (x, y, z) grid coordinates to a linear index.
Panics
In debug builds, panics if any coordinate is out of range.
Sourcepub fn coords(&self, idx: usize) -> (usize, usize, usize)
pub fn coords(&self, idx: usize) -> (usize, usize, usize)
Convert a linear index back to (x, y, z) coordinates.
Sourcepub fn occupied_count(&self) -> usize
pub fn occupied_count(&self) -> usize
Count occupied voxels.