Auto-generated module
🤖 Generated with SplitRS
Functions
- compute_
angular_ momentum - Compute the total angular momentum of all alive particles about the origin.
- compute_
center_ of_ mass - Compute center of mass of all alive particles.
- compute_
morton_ codes - Compute Morton codes for all alive particles in a buffer.
- compute_
total_ momentum - Compute total momentum of all alive particles: sum(m * v).
- compute_
velocity_ histogram - Compute a velocity-speed histogram for all alive particles.
- emit_
burst - Emit a burst of
countparticles fromoriginwith the given velocity and lifetime, using an internal LCG for per-particle spread. - extract_
render_ data - Extract rendering data from a particle buffer.
- morton_
encode - Morton code (Z-order curve) interleave for a 3D position.
- prepare_
sorted_ render_ data - Prepare GPU particle rendering data sorted back-to-front for transparency.
- sort_
particles_ morton - Reorder a particle buffer according to Morton-sorted indices.